Astro.Supervisor (Astro v2.1.0)

Copy Markdown View Source

Provides a supervision tree under which the required TzWorld backend server can be started.

Summary

Functions

Starts a TzWorld backend module that manages the time zone data required for Astro to operate.

Functions

start_link(type \\ [], args \\ [])

Starts a TzWorld backend module that manages the time zone data required for Astro to operate.

The backend process is started under a supervisor called Astro.Supervisor.